callgraph

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package callgraph provides a backward-compatible wrapper for perflib/callgraph. The generator.go file is intentionally left empty because all types and functions are now defined via type aliases in model.go, delegating to perflib/callgraph.

Package callgraph provides unified call graph data structures and utilities. This package delegates to perflib/callgraph and provides type aliases for backward compatibility.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CallGraph

type CallGraph = libcg.CallGraph

CallGraph represents the complete call graph structure.

func NewCallGraph

func NewCallGraph() *CallGraph

NewCallGraph creates a new call graph.

type CallGraphAnalysis

type CallGraphAnalysis = libcg.CallGraphAnalysis

CallGraphAnalysis holds the complete enhanced analysis data.

type CalleeInfo

type CalleeInfo = libcg.CalleeInfo

CalleeInfo represents information about a callee of a function.

type CallerInfo

type CallerInfo = libcg.CallerInfo

CallerInfo represents information about a caller of a function.

type DOTWriter

type DOTWriter = libcg.DOTWriter

DOTWriter writes call graph data in DOT format.

func NewDOTWriter

func NewDOTWriter() *DOTWriter

NewDOTWriter creates a new DOT format writer.

type Edge

type Edge = libcg.Edge

Edge represents an edge (call relationship) in the call graph.

type FunctionAnalysis

type FunctionAnalysis = libcg.FunctionAnalysis

FunctionAnalysis provides detailed analysis for a single function.

type Generator

type Generator = libcg.Generator

Generator generates call graph data from parsed samples.

func NewGenerator

func NewGenerator(opts *GeneratorOptions) *Generator

NewGenerator creates a new call graph generator.

type GeneratorOptions

type GeneratorOptions = libcg.GeneratorOptions

GeneratorOptions holds configuration options for the call graph generator.

func DefaultGeneratorOptions

func DefaultGeneratorOptions() *GeneratorOptions

DefaultGeneratorOptions returns default generator options.

type GzipWriter

type GzipWriter = writer.GzipWriter[*CallGraph]

GzipWriter writes call graph data as gzipped JSON.

func NewGzipWriter

func NewGzipWriter() *GzipWriter

NewGzipWriter creates a new gzip writer with default compression.

type HotPath

type HotPath = libcg.HotPath

HotPath represents a critical/hot execution path.

type JSONWriter

type JSONWriter = writer.JSONWriter[*CallGraph]

JSONWriter writes call graph data as JSON.

func NewJSONWriter

func NewJSONWriter() *JSONWriter

NewJSONWriter creates a new JSON writer.

func NewPrettyJSONWriter

func NewPrettyJSONWriter() *JSONWriter

NewPrettyJSONWriter creates a JSON writer with pretty printing.

type ModuleAnalysis

type ModuleAnalysis = libcg.ModuleAnalysis

ModuleAnalysis provides aggregated analysis by module/package.

type Node

type Node = libcg.Node

Node represents a node in the call graph.

type Stats

type Stats = libcg.Stats

Stats returns statistics about the call graph.

type ThreadCallGraph

type ThreadCallGraph = libcg.ThreadCallGraph

ThreadCallGraph represents a call graph for a single thread.

func NewThreadCallGraph

func NewThreadCallGraph(tid int, threadName string) *ThreadCallGraph

NewThreadCallGraph creates a new thread-specific call graph.

type ThreadGroupAnalysis

type ThreadGroupAnalysis = libcg.ThreadGroupAnalysis

ThreadGroupAnalysis provides aggregated analysis by thread group.

type WriteResult

type WriteResult = writer.WriteResult

WriteResult is an alias to the common writer.WriteResult.

type XDotEdge

type XDotEdge = libcg.XDotEdge

XDotEdge represents an edge in xdot_json format.

type XDotJSONOutput

type XDotJSONOutput = libcg.XDotJSONOutput

XDotJSONOutput represents the xdot_json format compatible with graphviz.

type XDotObject

type XDotObject = libcg.XDotObject

XDotObject represents a node in xdot_json format.

type XDotWriter

type XDotWriter = libcg.XDotWriter

XDotWriter writes call graph data in xdot_json format.

func NewXDotWriter

func NewXDotWriter() *XDotWriter

NewXDotWriter creates a new xdot writer.

Jump to